function [meanimage,sdimage] = calcmeansd(files,outputdir,maskfile)
if nargin == 0 || size(files,1) == 0
    files = spm_select(Inf,'image','Select images to be used to calculate mean and SD');
end

if nargin < 2
    outputdir = spm_select(1,'dir','Select an output directory');
    maskfile = '';
end

%% do initialization
numimages = size(files,1);
vols = spm_vol(files);
volout = struct('dim',vols(1).dim(1:3),...
            'dt',[spm_type('float32') spm_platform('bigend')],...
            'mat',vols(1).mat);
meanimage = zeros(vols(1).dim);
sdimage = zeros(vols(1).dim);
hold = 1; % trilinear interpolation
%% loop for slices
for p=1:volout(1).dim(3),
    B = spm_matrix([0 0 -p 0 0 0 1 1 1]);
    X=zeros(numimages,prod(volout.dim(1:2)));
    for i=1:numimages
        M = inv(B*inv(volout.mat)*vols(i).mat);
        d = spm_slice_vol(vols(i),M,volout.dim(1:2),[hold,NaN]);
        if ~spm_type(vols(i).dt(1),'nanrep'), d(d==0)=NaN; end
        X(i,:) = d(:)';
    end
    meanX = mean(X);
    meanimage(:,:,p) = reshape(meanX,volout.dim(1:2));
    stdX = sqrt(sum(((X - repmat(meanX,numimages,1)).^2))./(numimages-1));
    sdimage(:,:,p) = reshape(stdX,volout.dim(1:2));
end
%% masking
if ~isempty(maskfile)
    vol_mask = spm_vol(maskfile);
    mask = reslice_mask(vols(1),vol_mask);
    meanimage = meanimage.*mask;
    sdimage = sdimage.*mask;
end
%% Write mean image
volout.fname = fullfile(outputdir,'mean.nii');
spm_write_vol(volout,meanimage);
%% Write sd image
volout.fname = fullfile(outputdir,'sd.nii');
spm_write_vol(volout,sdimage);