function varargout = fy_ivac_get_defaults(defstr, varargin)
% Get/set the defaults values associated with an identifier
% FORMAT defval = fy_ivac_get_defaults(defstr)
% Return the defaults value associated with identifier "defstr". 
% Currently, this is a '.' subscript reference into the global  
% "defaults" variable defined in spm_defaults.m.
%
% FORMAT fy_ivac_get_defaults(defstr, defval)
% Sets the ivac value associated with identifier "defstr". The new
% ivac value applies immediately to:
% * new modules in batch jobs
% * modules in batch jobs that have fnot been saved yet
% This value will not be saved for future sessions of SPM. To make
% persistent changes, edit fy_ivac_defaults.m.
%__________________________________________________________________________
% Copyright (C) 2014 Fumio Yamashita

% based on Volkmar Glauches version of
% spm_get_defaults and cg_vbm8_get_defaults.m 404 by C gazer
% fy_ivac_get_defaults.m 100 2013-02-12 fumio  
global ivac;
if isempty(ivac)
    fy_ivac_defaults;
end

% construct subscript reference struct from dot delimited tag string
tags = textscan(defstr,'%s', 'delimiter','.');
subs = struct('type','.','subs',tags{1}');

if nargin == 1
    varargout{1} = subsref(ivac, subs);
else
    ivac = subsasgn(ivac, subs, varargin{1});
end
