function job = tbx_cfg_ivac
% Configuration file for iVAC toolbox
% based on Christian Gaser's tbx_cfg_tom8.m 7 2009-09-30 14:25:20
% Fumio Yamashita
% fy_cfg_ivac.m 2012-07-25 14:09:00

addpath(fullfile(spm('dir'),'toolbox','iVAC'));

% ---------------------------------------------------------------------
% Images
% ---------------------------------------------------------------------
Image         = cfg_files;
Image.tag     = 'images';
Image.name    = 'Images';
Image.help    = {'Select images for creating database.'};
Image.filter = 'image';
Image.ufilter = '.*';
Image.num     = [1 Inf];
% ---------------------------------------------------------------------
% Mask image
% ---------------------------------------------------------------------
mask          = cfg_files;
mask.tag     = 'mask';
mask.name    = 'Mask image';
mask.help    = {'Select a mask image.'};
mask.filter  = 'image';
mask.ufilter = '.*';
mask.val     = {{''}};
mask.num     = [0 1];
% ---------------------------------------------------------------------
% c Vector
% ---------------------------------------------------------------------
c         = cfg_entry;
c.tag     = 'c';
c.name    = 'Vector';
c.help    = {'Vector of covariate values'};
c.strtype = 'e';
c.num     = [Inf    1];
% ---------------------------------------------------------------------
% age Age
% ---------------------------------------------------------------------
age         = cfg_branch;
age.tag     = 'age';
age.name    = 'Age';
age.val     = {c};
age.help    = {
    'Enter subjects age in years; for increased accuracy, values like '
    '10.5 or 7.3 are permissable. This field must be filled.'
    }';
% ---------------------------------------------------------------------
% poly3 Cubic
% ---------------------------------------------------------------------
poly3         = cfg_const;
poly3.tag     = 'poly3';
poly3.name    = 'Cubic';
poly3.val = {[]};
poly3.help    = {'Model linear, quadratic, and cubic age effects (1st, 2nd, and 3rd order)'};
% ---------------------------------------------------------------------
% poly2 Quadratic
% ---------------------------------------------------------------------
poly2         = cfg_const;
poly2.tag     = 'poly2';
poly2.name    = 'Quadratic';
poly2.val = {[]};
poly2.help    = {'Model linear and quadratic age effects (1st and 2nd order)'};
% ---------------------------------------------------------------------
% poly1 Linear
% ---------------------------------------------------------------------
poly1         = cfg_const;
poly1.tag     = 'poly1';
poly1.name    = 'Linear';
poly1.val = {[]};
poly1.help    = {'Model only linear age effects (1st order only)'};
% ---------------------------------------------------------------------
% poly Order of polynomial age regression?
% ---------------------------------------------------------------------
poly         = cfg_choice;
poly.tag     = 'poly';
poly.name    = 'Order of polynomial age regression?';
poly.help    = {'Age can be modeled as polynomial regression with up to third order terms. The simplest model is a linear regression (which is not recommended).Either third or second order regression is appropriate for modeling aging effects. The different age terms will be orthogonalized with regard to its preceeding column.'};
poly.values  = {poly3 poly2 poly1};
% ---------------------------------------------------------------------
% c Vector
% ---------------------------------------------------------------------
c         = cfg_entry;
c.tag     = 'c';
c.name    = 'Vector';
c.help    = {'Vector of covariate values'};
c.strtype = 'e';
c.num     = [Inf    1];
% ---------------------------------------------------------------------
% Gender
% ---------------------------------------------------------------------
gender         = cfg_branch;
gender.tag     = 'gender';
gender.name    = 'Gender';
gender.val     = {c};
gender.help    = {'Enter subjects gender as a vector of 0 (female) and 1 (male).'};
% ---------------------------------------------------------------------
% c Vector
% ---------------------------------------------------------------------
c         = cfg_entry;
c.tag     = 'c';
c.name    = 'Vector';
c.help    = {'Vector of covariate values'};
c.strtype = 'e';
c.num     = [Inf    1];
% ---------------------------------------------------------------------
% cname Name
% ---------------------------------------------------------------------
cname         = cfg_entry;
cname.tag     = 'cname';
cname.name    = 'Name';
cname.help    = {'Name of covariate'};
cname.strtype = 's';
cname.num     = [1  Inf];
% ---------------------------------------------------------------------
% cov Additional Covariate
% ---------------------------------------------------------------------
cov         = cfg_branch;
cov.tag     = 'cov';
cov.name    = 'Additional Covariate';
cov.val     = {c cname};
cov.help    = {'Add a new covariate to your experimental design'};
% ---------------------------------------------------------------------
% covariates Covariates
% ---------------------------------------------------------------------
covariates         = cfg_repeat;
covariates.tag     = 'covariates';
covariates.name    = 'Covariates';
covariates.help    = {'If you want to model the effects of additional covariates of interests, those can be entered here. Only covariates that explain a substantial amount of variance in the data should be included here. This step is optional.'};
covariates.values  = {cov};
covariates.num     = [0 Inf];
% ---------------------------------------------------------------------
% regression Regression approach
% ---------------------------------------------------------------------
regression         = cfg_branch;
regression.tag     = 'regression';
regression.name    = 'Regression approach';
regression.val = {age poly gender covariates};
regression.help    = {'Use regression approach to create database.'};
% ---------------------------------------------------------------------
% meansd Mean and standard deviation approach
% ---------------------------------------------------------------------
meansd         = cfg_const;
meansd.tag     = 'meansd';
meansd.name    = 'Mean and standard deviation approach';
meansd.val = {[]};
meansd.help    = {'Create database based on mean and standard deviation.'};
% ---------------------------------------------------------------------
% database Select database creation method
% ---------------------------------------------------------------------
database         = cfg_choice;
database.tag     = 'database';
database.name    = 'Database creation method';
database.help    = {
    'Two methods for database construction, stratified and regression method can be selected. '
    'Stratified method calculates mean and standard deviation of a normal control group for each voxel, to compute '
    'z-score of a target subject by the formula,'
    'z-score = ([control mean]?[target subjects value])/(control S.D.).' 
    'Regression method estimates normative ranges by multiple regression using the general linear model framework, '
    'and calculates z-score using prediction calculation.'
    }';
database.values  = {regression meansd};
database.val  = {regression};
% ---------------------------------------------------------------------
% odir Output Directory
% ---------------------------------------------------------------------
odir         = cfg_files;
odir.tag     = 'odir';
odir.name    = 'Output Directory';
odir.help    = {
    'This defaults to the current work directory. It is, however, a good '
    'idea to create a separate directory with a meaningful name for each project.'
    }';
odir.filter = 'dir';
odir.ufilter = '.*';
odir.num     = [1 1];
% ---------------------------------------------------------------------
% create Create database
% ---------------------------------------------------------------------
create         = cfg_exbranch;
create.tag     = 'create';
create.name    = 'Create database';
create.val     = {Image mask database odir};
create.check   = @create_check;
create.help    = {'Create new database by regression modeling.'};
create.prog    = @(job)fy_ivac('create',job);
create.vout    = @(job)fy_ivac_vout('create',job);
%% Individual analysis
% ---------------------------------------------------------------------
% Images
% ---------------------------------------------------------------------
Image         = cfg_files;
Image.tag     = 'images';
Image.name    = 'Images';
Image.help    = {'Select images to analyze.'};
Image.filter = 'image';
Image.ufilter = '.*';
Image.num     = [1 Inf];
% ---------------------------------------------------------------------
% Mask image
% ---------------------------------------------------------------------
mask          = cfg_files;
mask.tag     = 'mask';
mask.name    = 'Mask image';
mask.help    = {'Select a mask image.'};
mask.filter  = 'image';
mask.ufilter = '.*';
mask.val     = {{''}};
mask.num     = [0 1];
% ---------------------------------------------------------------------
% ivacmat Select iVAC.mat
% ---------------------------------------------------------------------
ivacmat         = cfg_files;
ivacmat.tag     = 'ivacmat';
ivacmat.name    = 'Select iVAC.mat';
ivacmat.help    = {'Select the iVAC.mat file that contains the regression parameters.'};
ivacmat.filter = 'mat';
ivacmat.ufilter = '^iVAC\.mat$';
ivacmat.num     = [1 1];
% ---------------------------------------------------------------------
% beta images
% ---------------------------------------------------------------------
betaimage     = cfg_files;
betaimage.tag = 'betaimages';
betaimage.name    = 'Betaimages';
betaimage.help    = {'Select beta images.'};
betaimage.filter = 'image';
betaimage.ufilter = '^beta\.nii$';
betaimage.num     = [1 Inf];
% ---------------------------------------------------------------------
% beta cov images
% ---------------------------------------------------------------------
%betacovimage         = cfg_files;
%betacovimage.tag     = 'betacovimages';
%betacovimage.name    = 'Betacovimages';
%betacovimage.help    = {'Select beta covariance images.'};
%betacovimage.filter = 'image';
%betacovimage.ufilter = '^betacov\.nii$';
%betacovimage.num     = [1 Inf];
% ---------------------------------------------------------------------
% sigma image
% ---------------------------------------------------------------------
sigmaimage         = cfg_files;
sigmaimage.tag     = 'sigmaimage';
sigmaimage.name    = 'Sigmaimage';
sigmaimage.help    = {'Select a sigma image.'};
sigmaimage.filter = 'image';
sigmaimage.ufilter = '^sigma\.nii$';
sigmaimage.num     = [1 Inf];
% ---------------------------------------------------------------------
% c Vector
% ---------------------------------------------------------------------
c         = cfg_entry;
c.tag     = 'c';
c.name    = 'Vector';
c.help    = {'Vector of covariate values'};
c.strtype = 'e';
c.num     = [Inf    1];
% ---------------------------------------------------------------------
% age Age
% ---------------------------------------------------------------------
age         = cfg_branch;
age.tag     = 'age';
age.name    = 'Age';
age.val     = {c};
age.help    = {
    'Enter subjects age in years; for increased accuracy, values like '
    '10.5 or 7.3 are permissable. This field must be filled.'
    }';
% ---------------------------------------------------------------------
% c Vector
% ---------------------------------------------------------------------
c         = cfg_entry;
c.tag     = 'c';
c.name    = 'Vector';
c.help    = {'Vector of covariate values'};
c.strtype = 'e';
c.num     = [Inf    1];
% ---------------------------------------------------------------------
% Gender
% ---------------------------------------------------------------------
gender         = cfg_branch;
gender.tag     = 'gender';
gender.name    = 'Gender';
gender.val     = {c};
gender.help    = {'Enter subjects gender as a vector of 0 (female) and 1 (male).'};
% ---------------------------------------------------------------------
% c Vector
% ---------------------------------------------------------------------
c         = cfg_entry;
c.tag     = 'c';
c.name    = 'Vector';
c.help    = {'Vector of covariate values'};
c.strtype = 'e';
c.num     = [Inf    1];
% ---------------------------------------------------------------------
% cname Name
% ---------------------------------------------------------------------
cname         = cfg_entry;
cname.tag     = 'cname';
cname.name    = 'Name';
cname.help    = {'Name of covariate'};
cname.strtype = 's';
cname.num     = [1  Inf];
% ---------------------------------------------------------------------
% cov Additional Covariate
% ---------------------------------------------------------------------
cov         = cfg_branch;
cov.tag     = 'cov';
cov.name    = 'Additional Covariate';
cov.val     = {c cname};
cov.help    = {'Add a new covariate to your experimental design'};
% ---------------------------------------------------------------------
% covariates Covariates
% ---------------------------------------------------------------------
covariates         = cfg_repeat;
covariates.tag     = 'covariates';
covariates.name    = 'Covariates';
covariates.help    = {'If you want to model the effects of additional covariates of interests, those can be entered here. Only covariates that explain a substantial amount of variance in the data should be included here. This step is optional.'};
covariates.values  = {cov};
covariates.num     = [0 Inf];
% ---------------------------------------------------------------------
% outputimage
% ---------------------------------------------------------------------
outputimage         = cfg_menu;
outputimage.tag     = 'outputimage';
outputimage.name    = 'Output images';
outputimage.labels = {'t-image','z-score image','t- and z-score image'};
outputimage.values = {0 1 2};
outputimage.val = {1};
outputimage.help    = {'Select output for statistical images.'};
% ---------------------------------------------------------------------
% regression Regression approach
% ---------------------------------------------------------------------
regression         = cfg_branch;
regression.tag     = 'regression';
regression.name    = 'Regression';
%regression.val = {ivacmat betaimage betacovimage sigmaimage age gender covariates outputimage};
regression.val = {ivacmat betaimage sigmaimage age gender covariates outputimage};
regression.help    = {'Use regression coefficients to calculate prediction intervals'};
% ---------------------------------------------------------------------
% beta images
% ---------------------------------------------------------------------
meanimage     = cfg_files;
meanimage.tag = 'meanimage';
meanimage.name    = 'Mean image';
meanimage.help    = {'Select a mean image.'};
meanimage.filter = 'image';
meanimage.ufilter = '^mean.*\.nii$';
meanimage.num     = [1 1];
% ---------------------------------------------------------------------
% beta cov images
% ---------------------------------------------------------------------
sdimage         = cfg_files;
sdimage.tag     = 'sdimage';
sdimage.name    = 'SD image';
sdimage.help    = {'Select a standard deviation image.'};
sdimage.filter = 'image';
sdimage.ufilter = '^sd.*\.nii$';
sdimage.num     = [1 1];
% ---------------------------------------------------------------------
% meansd Mean and standard deviation approach
% ---------------------------------------------------------------------
meansd         = cfg_branch;
meansd.tag     = 'meansd';
meansd.name    = 'Mean and standard deviation';
meansd.val = {meanimage sdimage};
meansd.help    = {'Use mean and standard deviation images as reference database.'};
% ---------------------------------------------------------------------
% database Select database creation method
% ---------------------------------------------------------------------
database         = cfg_choice;
database.tag     = 'database';
database.name    = 'Select database type';
database.help    = {'wv'};
database.values  = {regression meansd};
database.val  = {regression};
% ---------------------------------------------------------------------
% odir Output Directory
% ---------------------------------------------------------------------
odir         = cfg_files;
odir.tag     = 'odir';
odir.name    = 'Output Directory';
odir.val{1} = {''};
odir.help    = {
    'Images produced by this function will be written into this output directory.'
    'If no directory is given, images will be written to each directory containing original files.'
    }';
odir.filter = 'dir';
odir.ufilter = '.*';
odir.num     = [0 1];
% ---------------------------------------------------------------------
% analysis Individual analysis
% ---------------------------------------------------------------------
analysis         = cfg_exbranch;
analysis.tag     = 'analysis';
analysis.name    = 'Individual analysis';
analysis.val     = {Image mask database odir};
analysis.check   = @analysis_check;
analysis.help    = {'Do individual analysis.'};
analysis.prog    = @(job)fy_ivac('analysis',job);
analysis.vout    = @(job)fy_ivac_vout('analysis',job);
% ---------------------------------------------------------------------
% ivacmat Select iVAC.mat
% ---------------------------------------------------------------------
%ivacmat         = cfg_files;
%ivacmat.tag     = 'ivacmat';
%ivacmat.name    = 'Select iVAC.mat';
%ivacmat.help    = {'Select the iVAC.mat file that contains the database parameters.'};
%ivacmat.filter = 'mat';
%ivacmat.ufilter = '^iVAC\.mat$';
%ivacmat.num     = [1 1];
%% ROI analysis
% ---------------------------------------------------------------------
% Images
% ---------------------------------------------------------------------
Image         = cfg_files;
Image.tag     = 'images';
Image.name    = 'Images';
Image.help    = {'Select statistial images to be render or overlay.'};
Image.filter = 'image';
Image.ufilter = '.*';
Image.num     = [1 Inf];
% ---------------------------------------------------------------------
% ROI image
% ---------------------------------------------------------------------
roi          = cfg_files;
roi.tag     = 'roi';
roi.name    = 'ROI image';
roi.help    = {'Select a ROI image.'};
roi.filter  = 'image';
roi.ufilter = '.*';
roi.val     = {{''}};
roi.num     = [0 1];
% ---------------------------------------------------------------------
% Mask image
% ---------------------------------------------------------------------
mask          = cfg_files;
mask.tag     = 'mask';
mask.name    = 'Mask image';
mask.help    = {'Select a mask image.'};
mask.filter  = 'image';
mask.ufilter = '.*';
mask.val     = {{''}};
mask.num     = [0 1];
% ---------------------------------------------------------------------
% odir Output Directory
% ---------------------------------------------------------------------
odir         = cfg_files;
odir.tag     = 'odir';
odir.name    = 'Output Directory';
odir.help    = {
    'This defaults to the current work directory. It is, however, a good '
    'idea to create a separate directory with a meaningful name for each project.'
    }';
odir.filter = 'dir';
odir.ufilter = '.*';
odir.num     = [1 1];
% ---------------------------------------------------------------------
% roianalysis Save ROI result
% ---------------------------------------------------------------------
roianalysis         = cfg_exbranch;
roianalysis.tag     = 'roianalysis';
roianalysis.name    = 'ROI analysis';
roianalysis.val     = {Image roi mask odir};
%render.check   = @render_check;
roianalysis.help    = {'ROI analysis'};
roianalysis.prog    = @(job)fy_ivac('roianalysis',job);
roianalysis.vout    = @(job)fy_ivac_vout('roianalysis',job);
%% Render and slice overlay
% ---------------------------------------------------------------------
% Images
% ---------------------------------------------------------------------
Image         = cfg_files;
Image.tag     = 'images';
Image.name    = 'Images';
Image.help    = {'Select statistial images to be render or overlay.'};
Image.filter = 'image';
Image.ufilter = '.*';
Image.num     = [1 Inf];
% ---------------------------------------------------------------------
% Render file
% ---------------------------------------------------------------------
renderfile         = cfg_files;
renderfile.tag     = 'renderfile';
renderfile.name    = 'Render file';
renderfile.help    = {'Select render file.'};
renderfile.filter = 'render';
renderfile.ufilter = '.*';
renderfile.def     = @(val)fy_ivac_get_defaults('report.rendfile' , val{:});
renderfile.num     = [1 1];
% ---------------------------------------------------------------------
% Template file
% ---------------------------------------------------------------------
templatefile         = cfg_files;
templatefile.tag     = 'templatefile';
templatefile.name    = 'Template file';
templatefile.help    = {'Select template file.'};
templatefile.filter = 'image';
templatefile.ufilter = '.*';
templatefile.def     = @(val)fy_ivac_get_defaults('report.template' , val{:});
templatefile.num     = [1 1];
% ---------------------------------------------------------------------
% c Vector
% ---------------------------------------------------------------------
c         = cfg_entry;
c.tag     = 'c';
c.name    = 'Vector';
c.help    = {'Vector of covariate values'};
c.strtype = 'e';
c.val     = {[1 5]};
c.num     = [1 2];
% ---------------------------------------------------------------------
% range Value range
% ---------------------------------------------------------------------
range         = cfg_branch;
range.tag     = 'range';
range.name    = 'range';
range.val     = {c};
range.help    = {
    'Enter value range of statistical image to render or overlay'
    }';
% ---------------------------------------------------------------------
% format3 PDF format
% ---------------------------------------------------------------------
format3         = cfg_const;
format3.tag     = 'pdf';
format3.name    = 'pdf';
format3.val = {[]};
format3.help    = {'PDF format'};
% ---------------------------------------------------------------------
% format2 Tiff format
% ---------------------------------------------------------------------
format2         = cfg_const;
format2.tag     = 'tiff';
format2.name    = 'tiff';
format2.val = {[]};
format2.help    = {'TIFF format'};
% ---------------------------------------------------------------------
% format1 PNG format
% ---------------------------------------------------------------------
format1         = cfg_const;
format1.tag     = 'png';
format1.name    = 'png';
format1.val = {[]};
format1.help    = {'PNG format'};
% ---------------------------------------------------------------------
% format print format
% ---------------------------------------------------------------------
format         = cfg_choice;
format.tag     = 'format';
format.name    = 'Output image file format';
format.help    = {'Output image file format'};
format.values  = {format1 format2 format3};
format.val     = {format3};
% ---------------------------------------------------------------------
% odir Output Directory
% ---------------------------------------------------------------------
odir         = cfg_files;
odir.tag     = 'odir';
odir.name    = 'Output Directory';
odir.val{1} = {''};
odir.help    = {
    'Images produced by this function will be written into this output directory.'
    'If no directory is given, images will be written to each directory containing original files.'
    }';
odir.filter = 'dir';
odir.ufilter = '.*';
odir.num     = [0 1];
% ---------------------------------------------------------------------
% render Save report
% ---------------------------------------------------------------------
render         = cfg_exbranch;
render.tag     = 'render';
render.name    = 'Save report';
render.val     = {Image renderfile templatefile range format odir};
%render.check   = @render_check;
render.help    = {'Save report - render and slice overlay'};
render.prog    = @(job)fy_ivac('render',job);
render.vout    = @(job)fy_ivac_vout('render',job);
% ---------------------------------------------------------------------
% ivacmat Select iVAC.mat
% ---------------------------------------------------------------------
ivacmat         = cfg_files;
ivacmat.tag     = 'ivacmat';
ivacmat.name    = 'Select iVAC.mat';
ivacmat.help    = {'Select the iVAC.mat file that contains the database parameters.'};
ivacmat.filter = 'mat';
ivacmat.ufilter = '^iVAC\.mat$';
ivacmat.num     = [1 1];
% ---------------------------------------------------------------------
% getinfo Print information about iVAC.mat
% ---------------------------------------------------------------------
getinfo         = cfg_exbranch;
getinfo.tag     = 'getinfo';
getinfo.name    = 'Print information about iVAC.mat';
getinfo.val     = {ivacmat};
getinfo.help    = {'Print information about a already created dababase.'};
getinfo.prog = @(job)fy_ivac('getinfo',job);
% ---------------------------------------------------------------------
% ivac Individual voxel-based morphometry adjusting covariates
% ---------------------------------------------------------------------
job         = cfg_choice;
job.tag     = 'ivac';
job.name    = 'iVAC';
job.help    = {'Help needed'};
job.values  = {create analysis roianalysis render getinfo};

return;

%-------------------------------------------------------------------------

%-------------------------------------------------------------------------

function t = create_check(job)
t = {};

if isfield(job.database,'meansd')
    return;
end

n_covs  = length(job.database.regression.cov);
n_modi = length(job.images);

% check for correct number of covariates
if n_modi~=size(job.database.regression.age.c,1), t = {sprintf('Number of age values differ from number of images.\n')}; end
if n_modi~=size(job.database.regression.gender.c,1), t = {t{:}, sprintf('Number of gender values differ from number of images.\n')}; end
for i = 1:n_covs
    if n_modi(1)~=size(job.database.regression.cov(i).c,1)
        t = {t{:}, sprintf('Number of %s differ from number of images.\n',job.database.regression.cov(i).cname)};
    end
end

if (min(job.database.regression.gender.c)<0) | (max(job.database.regression.gender.c)>1)
    t = {t{:}, sprintf('Valid values for gender are 1 for males and 0 for females.')};
end

return

function t = analysis_check(job)
t = {};

if isfield(job.database,'meansd')
    return;
end

load(job.database.regression.ivacmat{:});
[path,name,ext] = spm_fileparts(job.database.regression.betaimages{1});
betaimage = fullfile(path,[name ext]);
%betacovimage = job.database.regression.betacovimages{1};
%[path,name,ext] = spm_fileparts(betacovimage);
%betacovimage = fullfile(path,[name ext]);
vol_beta = spm_vol(betaimage);
%vol_betacov = spm_vol(betacovimage);

%if length(vol_beta)^2 ~= length(vol_betacov)
%    t = {sprintf('Number of dimensions of beta and beta covariance images did not match.\n')};
%end

n_covs  = length(job.database.regression.cov);
n_modi = length(job.images);

if  (ageDegree+2+n_covs) ~= length(vol_beta)
    t = {sprintf('Number of regression coefficients and beta images did not match.\n')};
end

% check for correct number of covariates
if n_modi~=size(job.database.regression.age.c,1), t = {t{:},sprintf('Number of age values differ from number of images.\n')}; end
if n_modi~=size(job.database.regression.gender.c,1), t = {t{:}, sprintf('Number of gender values differ from number of images.\n')}; end
for i = 1:n_covs
    if n_modi(1)~=size(job.database.regression.cov(i).c,1)
        t = {t{:}, sprintf('Number of %s differ from number of images.\n',job.database.regression.cov(i).cname)};
    end
end

if (min(job.database.regression.gender.c)<0) || (max(job.database.regression.gender.c)>1)
    t = {t{:}, sprintf('Valid values for gender are 1 for males and 0 for females.')};
end

return
%-------------------------------------------------------------------------

function dep = fy_ivac_vout(cmd, job) %#ok<INUSD>
switch lower(cmd)
    case 'create',
        dep(1)            = cfg_dep;
        dep(1).sname      = 'iVAC.mat';
        dep(1).src_output = substruct('.','ivacmat');
        dep(1).tgt_spec   = cfg_findspec({{'strtype','e','filter','mat'}});
        dep(2)            = cfg_dep;
        dep(2).sname      = 'Beta images';
        dep(2).src_output = substruct('.','betas');
        dep(2).tgt_spec   = cfg_findspec({{'strtype','e','filter','image'}});
        dep(3)            = cfg_dep;
        dep(3).sname      = 'Sigma image';
        dep(3).src_output = substruct('.','sigma');
        dep(3).tgt_spec   = cfg_findspec({{'strtype','e','filter','image'}});
    case 'analysis'
        dep(1)            = cfg_dep;
        dep(1).sname      = 'T-images';
        dep(1).src_output = substruct('.','timage');
        dep(1).tgt_spec   = cfg_findspec({{'strtype','e','filter','image'}});
        dep(2)            = cfg_dep;
        dep(2).sname      = 'Z-images';
        dep(2).src_output = substruct('.','zimage');
        dep(2).tgt_spec   = cfg_findspec({{'strtype','e','filter','image'}});
    case 'roianalysis'
        dep(1)            = cfg_dep;
        dep(1).sname      = 'ROIresult';
        dep(1).src_output = substruct('.','roiresult');
    case 'render'
        dep(1)            = cfg_dep;
        dep(1).sname      = 'Output report file';
        dep(1).src_output = substruct('.','report');
        dep(1).tgt_spec   = cfg_findspec({{'strtype','e','filter','any'}});
    otherwise
        error('fy_ivac:vout','No virtual outputs defined for ''%s''.', cmd);
end